@@ -4,14 +4,16 @@ import logging
 import os
 import sys
 import time
+from tqdm import tqdm
 from pathlib import Path
-
+from enum import IntEnum
 import numpy as np
 from PIL import Image
 
 logger = logging.getLogger("superannotate-python-sdk")
 
 _PROJECT_TYPES = {"Vector": 1, "Pixel": 2}
+
 _ANNOTATION_STATUSES = {
     "NotStarted": 1,
     "InProgress": 2,
@@ -21,6 +23,44 @@ _ANNOTATION_STATUSES = {
     "Skipped": 6
 }
 _USER_ROLES = {"Admin": 2, "Annotator": 3, "QA": 4, "Customer": 5, "Viewer": 6}
+_AVAILABLE_SEGMENTATION_MODELS = ['autonomous', 'generic']
+_MODEL_TRAINING_STATUSES = {
+    "NotStarted": 1,
+    "InProgress": 2,
+    "Completed": 3,
+    "FailedBeforeEvaluation": 4,
+    "FailedAfterEvaluation": 5,
+    "FailedAfterEvaluationWithSavedModel": 6
+}
+
+_PREDICTION_SEGMENTATION_STATUSES = {
+    "NotStarted": 1,
+    "InProgress": 2,
+    "Completed": 3,
+    "Failed": 4
+}
+
+
+def prediction_segmentation_status_from_str_to_int(status):
+    return _PREDICTION_SEGMENTATION_STATUSES[status]
+
+
+def prediction_segmentation_status_from_int_to_str(status):
+    for idx, item in _PREDICTION_SEGMENTATION_STATUSES.items():
+        if item == status:
+            return idx
+    raise RuntimeError("NA segmentation/prediction status")
+
+
+def model_training_status_int_to_str(project_status):
+    for item in _MODEL_TRAINING_STATUSES:
+        if _MODEL_TRAINING_STATUSES[item] == project_status:
+            return item
+    raise RuntimeError("NA training status")
+
+
+def model_training_status_str_to_int(project_status):
+    return _MODEL_TRAINING_STATUSES[project_status]
 
 
 def image_path_to_annotation_paths(image_path, project_type):
@@ -244,8 +284,35 @@ def dump_output(output_dir, platform, classes, files_dict):
         save_desktop_format(output_dir, classes, files_dict)
 
 
+def write_to_json(output_path, json_data):
+    with open(output_path, 'w') as fw:
+        json.dump(json_data, fw, indent=2)
+
+
 MAX_IMAGE_SIZE = 100 * 1024 * 1024  # 100 MB limit
 MAX_IMAGE_RESOLUTION = {
     "Vector": 100_000_000,
     "Pixel": 4_000_000
 }  # Resolution limit
+
+
+def process_api_response(data):
+    logger.info("Maintenance operations are being performed")
+    if 'metadata' not in data:
+        return data
+
+    return data['data']
+
+
+def tqdm_converter(
+    total_num, images_converted, images_not_converted, finish_event
+):
+    with tqdm(total=total_num) as pbar:
+        while True:
+            finished = finish_event.wait(5)
+            if not finished:
+                sum_all = len(images_converted) + len(images_not_converted)
+                pbar.update(sum_all - pbar.n)
+            else:
+                pbar.update(total_num - pbar.n)
+                break
