@@ -41,6 +41,7 @@ logger = logging.getLogger("superannotate-python-sdk")
 
 _api = API.get_instance()
 _NUM_THREADS = 10
+_TIME_TO_UPDATE_IN_TQDM = 1
 
 
 def create_project(project_name, project_description, project_type):
@@ -842,6 +843,24 @@ def upload_images_to_project(
     return (list_of_uploaded, list_of_not_uploaded, duplicate_images)
 
 
+def _tqdm_download(
+    total_num, images_to_upload, images_not_uploaded,
+    duplicate_images_filenames, finish_event
+):
+    with tqdm(total=total_num) as pbar:
+        while True:
+            finished = finish_event.wait(1)
+            if not finished:
+                sum_all = 0
+                sum_all += len(images_not_uploaded)
+                sum_all += len(images_to_upload)
+                sum_all += len(duplicate_images_filenames)
+                pbar.update(sum_all - pbar.n)
+            else:
+                pbar.update(total_num - pbar.n)
+                break
+
+
 def upload_images_from_public_urls_to_project(
     project,
     img_urls,
@@ -875,6 +894,18 @@ def upload_images_from_public_urls_to_project(
     images_to_upload = []
     duplicate_images_filenames = []
     path_to_url = {}
+
+    finish_event = threading.Event()
+    tqdm_thread = threading.Thread(
+        target=_tqdm_download,
+        args=(
+            len(img_urls), images_to_upload, images_not_uploaded,
+            duplicate_images_filenames, finish_event
+        ),
+        daemon=True
+    )
+    logger.info('Downloading %s images' % len(img_urls))
+    tqdm_thread.start()
     with tempfile.TemporaryDirectory() as save_dir_name:
         save_dir = Path(save_dir_name)
         for i, img_url in enumerate(img_urls):
@@ -906,6 +937,9 @@ def upload_images_from_public_urls_to_project(
 
                 path_to_url[str(img_path)] = img_url
                 images_to_upload.append(img_path)
+
+        finish_event.set()
+        tqdm_thread.join()
         images_uploaded_paths, images_not_uploaded_paths, duplicate_images_paths = upload_images_to_project(
             project,
             images_to_upload,
@@ -1163,7 +1197,8 @@ def __upload_annotations_thread(
             if not check_annotation_json(annotation_json):
                 couldnt_upload[thread_id].append(full_path)
                 logger.warning(
-                    "Annotation JSON %s missing width or height info", full_path
+                    "Annotation JSON %s missing width or height info. Skipping upload",
+                    full_path
                 )
                 continue
             fill_class_and_attribute_ids(
@@ -1398,7 +1433,8 @@ def __upload_preannotations_thread(
         if not check_annotation_json(annotation_json):
             couldnt_upload[thread_id].append(full_path)
             logger.warning(
-                "Annotation JSON %s missing width or height info", full_path
+                "Annotation JSON %s missing width or height info. Skipping upload",
+                full_path
             )
             continue
         fill_class_and_attribute_ids(annotation_json, annotation_classes_dict)
@@ -1427,7 +1463,7 @@ def __upload_preannotations_thread(
 def __tqdm_thread_upload(total_num, uploaded, couldnt_upload, finish_event):
     with tqdm(total=total_num) as pbar:
         while True:
-            finished = finish_event.wait(5)
+            finished = finish_event.wait(_TIME_TO_UPDATE_IN_TQDM)
             if not finished:
                 sum_all = 0
                 for i in couldnt_upload:
@@ -1445,7 +1481,7 @@ def __tqdm_thread_upload_annotations(
 ):
     with tqdm(total=total_num) as pbar:
         while True:
-            finished = finish_event.wait(5)
+            finished = finish_event.wait(_TIME_TO_UPDATE_IN_TQDM)
             if not finished:
                 sum_all = 0
                 for i in couldnt_upload:
@@ -1465,7 +1501,7 @@ def __tqdm_thread_upload_preannotations(
 ):
     with tqdm(total=total_num) as pbar:
         while True:
-            finished = finish_event.wait(5)
+            finished = finish_event.wait(_TIME_TO_UPDATE_IN_TQDM)
             if not finished:
                 sum_all = 0
                 for i in couldnt_upload:
