@@ -1,7 +1,7 @@
 import cv2 as cv
 import numpy as np
 
-from .coco_api import (encode, _toBbox, _area)
+from .coco_api import _area, _toBbox
 
 
 def __instance_object_commons_per_instance(
@@ -90,7 +90,6 @@ def sa_pixel_to_coco_panoptic_segmentation(
         instance_bitmask = np.isin(flat_mask, parts)
         segment_id = next(id_generator)
         ann_mask[instance_bitmask] = segment_id
-
         bbox = list(_toBbox(instance_bitmask))
         area = int(_area(instance_bitmask.astype(np.uint8)))
 
